@@ -2,6 +2,7 @@ from ujenkins.endpoints.builds import Builds
 from ujenkins.endpoints.jobs import Jobs
 from ujenkins.endpoints.nodes import Nodes
 from ujenkins.endpoints.plugins import Plugins
+from ujenkins.endpoints.queue import Queue
 from ujenkins.endpoints.system import System
 from ujenkins.endpoints.views import Views
 
@@ -10,6 +11,7 @@ __all__ = (
     'Jobs',
     'Nodes',
     'Plugins',
+    'Queue',
     'System',
     'Views',
 )
