@@ -2,7 +2,7 @@ import json
 import xml.etree.ElementTree
 
 from functools import partial
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List
 
 from ujenkins.exceptions import JenkinsError, JenkinsNotFoundError
 from ujenkins.helpers import parse_build_url
@@ -213,8 +213,8 @@ class Nodes:
             name (str):
                 Node name.
 
-            config (str):
-                XML config for new node.
+            config (dict):
+                Config for new node, see ujenkins.helpers.construct_node_config
 
         Returns:
             None
@@ -318,7 +318,7 @@ class Nodes:
 
         return self.jenkins._chain([callback1, callback2])
 
-    def disable(self, name: str, message: Optional[str] = '') -> None:
+    def disable(self, name: str, message: str = '') -> None:
         """
         Disable node if it enabled.
 
