@@ -1,6 +1,6 @@
 import json
 
-from typing import Dict, Optional
+from typing import Dict
 
 
 class Plugins:
@@ -8,7 +8,7 @@ class Plugins:
     def __init__(self, jenkins) -> None:
         self.jenkins = jenkins
 
-    def get(self, depth: Optional[int] = 2) -> Dict[str, dict]:
+    def get(self, depth: int = 2) -> Dict[str, dict]:
         """
         Get dict of all existed plugins in the system.
 
