@@ -103,8 +103,8 @@ def construct_job_config(*,
 
 def construct_node_config(*,
                           name: str,
-                          remote_fs: Optional[str] = '/tmp',
-                          executors: Optional[int] = 2
+                          remote_fs: str = '/tmp',
+                          executors: int = 2
                           ) -> dict:
     """
     Construct node config.
@@ -116,7 +116,7 @@ def construct_node_config(*,
         remote_fs (str):
             Remote node root directory.
 
-        executors (Optional[int]):
+        executors (int):
             Number of node executors
 
     Returns:
